"""Utilities for vasp files"""

from pypolymlp.core.data_format import PolymlpStructure


def print_poscar(st: PolymlpStructure):
    """Print structure in POSCAR format."""
    if st.comment is not None:
        print(st.comment)
    else:
        print("Generated by pypolymlp")

    print("1.0")
    for n in st.axis.T:
        print(
            "  ",
            "{0:15.15f}".format(n[0]),
            "{0:15.15f}".format(n[1]),
            "{0:15.15f}".format(n[2]),
        )
    index = 0
    print(" ", end="")
    for n in st.n_atoms:
        print(st.elements[index], " ", end="")
        index += n
    print()
    print(" ", end="")
    for n in st.n_atoms:
        print(n, " ", end="")
    print()
    print("Direct")
    for n in st.positions.T:
        print(
            "  ",
            "{0:15.15f}".format(n[0]),
            "{0:15.15f}".format(n[1]),
            "{0:15.15f}".format(n[2]),
        )


def write_poscar_file(
    st: PolymlpStructure,
    filename="poscar_pypolymlp",
    header=None,
):
    """Write structure in POSCAR file."""
    f = open(filename, "w")

    if header is not None:
        print(header, file=f)
    else:
        if st.comment is not None:
            print(st.comment, file=f)
        else:
            print("Generated by pypolymlp", file=f)

    print("1.0", file=f)
    for n in st.axis.T:
        print(
            "  ",
            "{0:15.15f}".format(n[0]),
            "{0:15.15f}".format(n[1]),
            "{0:15.15f}".format(n[2]),
            file=f,
        )
    index = 0
    print(" ", end="", file=f)
    for n in st.n_atoms:
        if n > 0:
            print(st.elements[index], " ", end="", file=f)
            index += n
        else:
            print("Z  ", end="", file=f)
    print("", file=f)
    print(" ", end="", file=f)
    for n in st.n_atoms:
        print(n, " ", end="", file=f)
    print("", file=f)
    print("Direct", file=f)
    for n in st.positions.T:
        print(
            "  ",
            "{0:15.15f}".format(float(n[0])),
            "{0:15.15f}".format(float(n[1])),
            "{0:15.15f}".format(float(n[2])),
            file=f,
        )

    f.close()
